/*
 * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 */

#ifndef __GDAUI_DECL_H_
#define __GDAUI_DECL_H_

/* 
 * Interfaces 
 */

typedef struct _GdauiDataProxy       GdauiDataProxy;
typedef struct _GdauiDataProxyIface  GdauiDataProxyIface;

/* 
 * Colors
 */
#define GDAUI_COLOR_NORMAL_NULL "#00cd66"
#define GDAUI_COLOR_PRELIGHT_NULL "#00ef77"

#define GDAUI_COLOR_NORMAL_DEFAULT "#6495ed"
#define GDAUI_COLOR_PRELIGHT_DEFAULT "#75a6fe"

#define GDAUI_COLOR_NORMAL_MODIF "#cacaee"
#define GDAUI_COLOR_PRELIGHT_MODIF "#cfcffe"

#define GDAUI_COLOR_NORMAL_INVALID "#ff6a6a"
#define GDAUI_COLOR_PRELIGHT_INVALID "#ff7b7b"

/*
 * Data of unknown status (no value available)
 */
#define GDAUI_COLOR_UNKNOWN_MASK .3, .3, .3, .6

#endif
